==> chaosmesh-model-6.0.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/LossSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LossSpecFluentImpl<A extends LossSpecFluent<A>> extends BaseFluent<A> implements LossSpecFluent<A>{
  public LossSpecFluentImpl() {
  }
  public LossSpecFluentImpl(LossSpec instance) {
    this.withCorrelation(instance.getCorrelation()); 
    this.withLoss(instance.getLoss()); 
  }
  private String correlation;
  private String loss;
  public String getCorrelation() {
    return this.correlation;
  }
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  public Boolean hasCorrelation() {
    return this.correlation != null;
  }
  public String getLoss() {
    return this.loss;
  }
  public A withLoss(String loss) {
    this.loss=loss; return (A) this;
  }
  public Boolean hasLoss() {
    return this.loss != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LossSpecFluentImpl that = (LossSpecFluentImpl) o;
    if (correlation != null ? !correlation.equals(that.correlation) :that.correlation != null) return false;
    if (loss != null ? !loss.equals(that.loss) :that.loss != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(correlation,  loss,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (loss != null) { sb.append("loss:"); sb.append(loss); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/LossSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LossSpecFluentImpl<A extends LossSpecFluent<A>> extends BaseFluent<A> implements LossSpecFluent<A>{
  public LossSpecFluentImpl() {
  }
  public LossSpecFluentImpl(LossSpec instance) {
    if (instance != null) {
      this.withCorrelation(instance.getCorrelation());
      this.withLoss(instance.getLoss());
    }
  }
  private String correlation;
  private String loss;
  public String getCorrelation() {
    return this.correlation;
  }
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  public Boolean hasCorrelation() {
    return this.correlation != null;
  }
  public String getLoss() {
    return this.loss;
  }
  public A withLoss(String loss) {
    this.loss=loss; return (A) this;
  }
  public Boolean hasLoss() {
    return this.loss != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LossSpecFluentImpl that = (LossSpecFluentImpl) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;

    if (!java.util.Objects.equals(loss, that.loss)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(correlation,  loss,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (loss != null) { sb.append("loss:"); sb.append(loss); }
    sb.append("}");
    return sb.toString();
  }
  
}
